@@ -1,13 +1,13 @@
 from .make_map import make_map
+from .trim_shapefile import trim_shapefile
 from .utils import (
     are_coordinates_in_shape,
-    extract_from_census_json,
     get_geojson_bounds,
 )
 
 __all__ = [
     make_map,
+    trim_shapefile,
     are_coordinates_in_shape,
-    extract_from_census_json,
     get_geojson_bounds,
 ]
